//
//
// Copyright (c) 2019 GetSocial BV. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <GetSocial/GetSocialActionButton.h>
#import <GetSocial/GetSocialAction.h>
#import <GetSocial/GetSocialConstants.h>
#import <GetSocial/GetSocialPostAuthor.h>

/*!
 * Type definition for different notification statuses.
 */
typedef NSString *GetSocialNotificationStatus NS_EXTENSIBLE_STRING_ENUM;

/*!
 * Notification is read.
 */
extern GetSocialNotificationStatus GetSocialNotificationStatusRead;

/*!
 * Notification is unread.
 */
extern GetSocialNotificationStatus GetSocialNotificationStatusUnread;

/*!
 * Notification is consumed.
 */
extern GetSocialNotificationStatus GetSocialNotificationStatusConsumed;

/*!
 * Notification is ignored.
 */
extern GetSocialNotificationStatus GetSocialNotificationStatusIgnored;

/*!
 * @typedef GetSocialNotificationType
 * @abstract Enumeration represents possible notification types.
 */
typedef NSString *GetSocialNotificationType NS_EXTENSIBLE_STRING_ENUM;

/*!
 * Someone commented on your activity.
 */
extern GetSocialNotificationType GetSocialNotificationTypeComment;

/*!
 * Someone liked your activity.
 */
extern GetSocialNotificationType GetSocialNotificationTypeLikeActivity;

/*!
 * Someone liked your comment.
 */
extern GetSocialNotificationType GetSocialNotificationTypeLikeComment;

/*!
 * Someone commented on the activity where you've commented before.
 */
extern GetSocialNotificationType GetSocialNotificationTypeRelatedComment;

/*!
 * You became friends with another user.
 */
extern GetSocialNotificationType GetSocialNotificationTypeNewFriendship;

/*!
 * Someone accepted your invite.
 */
extern GetSocialNotificationType GetSocialNotificationTypeInviteAccepted;

/*!
 * Someone mentioned you in comment.
 */
extern GetSocialNotificationType GetSocialNotificationTypeMentionInComment;

/*!
 * Someone mentioned you in activity.
 */
extern GetSocialNotificationType GetSocialNotificationTypeMentionInActivity;

/*!
 * Someone replied to your comment.
 */
extern GetSocialNotificationType GetSocialNotificationTypeReplyToComment;

/*!
 * Smart targeting Push Notifications.
 */
extern GetSocialNotificationType GetSocialNotificationTypeTargeting;

/*!
 * Notifications sent from the Dashboard when using "Test Push Notifications".
 */
extern GetSocialNotificationType GetSocialNotificationTypeDirect;

/*!
 * Notification sent from SDK.
 */
extern GetSocialNotificationType GetSocialNotificationTypeSDK;

#pragma mark - GetSocial Notification Key
/*!
 *  
 */
typedef NSString *GetSocialNotificationKey NS_EXTENSIBLE_STRING_ENUM DEPRECATED_ATTRIBUTE;

#pragma mark - GetSocial OpenActivity Notification Keys

/*!
 * GetSocialNotificationKey_OpenActivity_ActivityId and GetSocialNotificationKey_OpenActivity_FeedName are mutually exclusive.
 */
extern GetSocialNotificationKey GetSocialNotificationKey_OpenActivity_ActivityId DEPRECATED_ATTRIBUTE;

/*!
 * Optional. Can be present with GetSocialNotificationKey_OpenActivity_ActivityId only.
 */
extern GetSocialNotificationKey GetSocialNotificationKey_OpenActivity_CommentId DEPRECATED_ATTRIBUTE;

/*!
 * GetSocialNotificationKey_OpenActivity_ActivityId and GetSocialNotificationKey_OpenActivity_FeedName are mutually exclusive.
 */
extern GetSocialNotificationKey GetSocialNotificationKey_OpenActivity_FeedName DEPRECATED_ATTRIBUTE;

#pragma mark - GetSocial OpenProfile Notification Keys

/*!
 * ID of user to be opened.
 */
extern GetSocialNotificationKey GetSocialNotificationKey_OpenProfile_UserId DEPRECATED_ATTRIBUTE;

#pragma mark - GetSocial OpenUrl Notification Keys

/*!
 * URL to be opened.
 */
extern GetSocialNotificationKey GetSocialNotificationKey_OpenUrl_Url DEPRECATED_ATTRIBUTE;

/*!
 * Describes notification object.
 */
@interface GetSocialNotification : NSObject

/*!
 * Returns an enum value of the action.
 * @deprecated Use notificationAction property.
 */
@property(nonatomic, readonly) GetSocialNotificationActionType action DEPRECATED_ATTRIBUTE;

/*!
 * Returns an enum value of the type.
 */
@property(nonatomic, readonly) GetSocialNotificationType type;

/*!
 * Return was notification read by user or not.
 * @return YES, if notification was clicked by user or marked as read by developer.
 * @deprecated Use status property.
 */
@property(nonatomic, readonly) BOOL wasRead DEPRECATED_ATTRIBUTE;

/*!
 * Return notification status.
 */
@property(nonatomic, readonly) GetSocialNotificationStatus status;

/*!
 * Date of notification creation.
 * @return UNIX-timestamp of creation date in seconds.
 */
@property(nonatomic, readonly) NSUInteger createdAt;

/*!
 * Get the unique notification identifier.
 */
@property(nonatomic, copy, readonly) GetSocialId notificationId;

/*!
 * Data passed with action.
 * @deprecated Use notificationAction property.
 */
@property(nonatomic, strong, readonly) NSDictionary<GetSocialNotificationKey, NSString *> *actionData DEPRECATED_ATTRIBUTE;

/*!
 * Message of Push Notification.
 */
@property(nonatomic, copy, readonly) NSString *text;

/*!
 * Title of Push Notification.
 */
@property(nonatomic, copy, readonly) NSString *title;

/*!
 * Image url in Push Notification.
 */
@property(nonatomic, copy, readonly) NSString *imageUrl;

/*!
 * Video url in Push Notification.
 */
@property(nonatomic, copy, readonly) NSString *videoUrl;

/*!
 * Action to perform on notification click.
 */
@property(nonatomic, strong, readonly) GetSocialAction *notificationAction;

/*!
 * Action buttons with notifications.
 */
@property(nonatomic, strong, readonly) NSArray<GetSocialActionButton *> *actionButtons;

/*!
 * Notification sender.
 */
@property(nonatomic, strong, readonly) GetSocialUserReference* sender;

@end
